@@ -1,4 +1,4 @@
-# Copyright 2020 the authors.
+# Copyright 2021 the authors.
 # This file is part of Hy, which is free software licensed under the Expat
 # license. See the LICENSE.
 import sys
@@ -105,7 +105,7 @@ def _same_modules(source_module, target_module):
         try:
             if not inspect.ismodule(module):
                 loader = pkgutil.get_loader(module)
-                if loader:
+                if isinstance(loader, importlib.machinery.SourceFileLoader):
                     filename = loader.get_filename()
             else:
                 filename = inspect.getfile(module)
